@@ -72,6 +72,7 @@ _NSMAP = {'uddf': 'http://www.streit.cc/uddf/3.0/'}
 FORMAT_ID = 'id-{}'
 
 FMT_F = partial(str.format, '{0:.1f}')
+FMT_F2 = partial(str.format, '{0:.2f}')
 FMT_I = lambda v: '{}'.format(int(round(v)))
 FMT_DT = lambda dt: format(dt, '%Y-%m-%dT%H:%M:%S%z')
 
@@ -94,6 +95,7 @@ XP_DEFAULT_PROFILE_DATA =  (
     XPath('uddf:depth/text()'),
     XPath('uddf:divetime/text()'),
     XPath('uddf:temperature/text()'),
+    XPath('uddf:setpo2/text()'),
     XPath('uddf:decostop/@duration'),
     XPath('uddf:decostop/@decodepth'),
     XPath('uddf:alarm/text()'),
@@ -366,11 +368,11 @@ def dive_profile(node, fields=None, queries=None, parsers=None):
         find_data
     """
     if fields is None:
-        fields = ('depth', 'time', 'temp', 'deco_time', 'deco_depth',
-                'alarm', 'gas')
+        fields = ('depth', 'time', 'temp', 'setpoint',
+                'deco_time', 'deco_depth', 'alarm', 'gas')
         queries = XP_DEFAULT_PROFILE_DATA
         gases = dict(((gas.id, gas) for gas in gas_data(node)))
-        parsers = (float, ) * 5 + (str, gases.get)
+        parsers = (float, ) * 6 + (str, gases.get)
 
     return find_data('Sample', node, fields, queries, parsers,
             nquery=XP_WAYPOINT)
@@ -1018,6 +1020,7 @@ def create_dive_samples(samples):
                 ),
             xml.depth(FMT_F(s.depth)),
             xml.divetime(FMT_I(s.time)),
+            None if s.setpoint is None else xml.setpo2(FMT_F2(s.setpoint)),
             None if s.gas is None else xml.switchmix(ref=str(s.gas.id)),
             None if s.temp is None else xml.temperature(FMT_F(s.temp)),
         )
